Struct WpViewporter
pub struct WpViewporter { /* private fields */ }wayland and Linux only.Expand description
surface cropping and scaling
The global interface exposing surface cropping and scaling capabilities is used to instantiate an interface extension for a wl_surface object. This extended interface will then allow cropping and scaling the surface contents, effectively disconnecting the direct relationship between the buffer and the surface size.
This interface has no events.
Implementations
impl WpViewporter
impl WpViewporter
pub fn destroy(&self)
pub fn destroy(&self)
unbind from the cropping and scaling interface
Informs the server that the client will not be using this protocol object anymore. This does not affect any other objects, wp_viewport objects included.
pub fn get_viewport<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> WpViewport
pub fn get_viewport<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpViewport
extend surface interface for crop and scale
Instantiate an interface extension for the given wl_surface to crop and scale its content. If the given wl_surface already has a wp_viewport object associated, the viewport_exists protocol error is raised.